import{x as n,a as o,b as i,c,g as p,h as d,_,i as u,T as l,j as f,P as h,C as m,M as y,s as g,k as s,l as b,m as v,n as w,p as I}from"./outputWidgets.5ced94d7.js";import{u as k}from"./index.cec4fd9b.js";import"./pubsub.f395e26b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="5afd103a-0520-4c77-a254-02a71b28af19",e._sentryDebugIdIdentifier="sentry-dbid-5afd103a-0520-4c77-a254-02a71b28af19")}catch{}})();const x={};function A(e,t){const a=o("router-view");return i(),c(a,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const D=n(x,[["render",A]]),r=p({history:d("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.0c55cdaf.js"),["assets/Player.0c55cdaf.js","assets/index.48bbb941.js","assets/outputWidgets.5ced94d7.js","assets/outputWidgets.e6401203.css","assets/uuid.3b98222f.js","assets/broker.9e31ddd3.js","assets/index.cec4fd9b.js","assets/pubsub.f395e26b.js","assets/executeJs.11b87c77.js","assets/icons.157295a5.js","assets/CircularLoading.ee1c51bf.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.82b5545a.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.e0bb8b23.js","assets/Steps.998aa76d.css","assets/executeJs.ee59d5a5.css","assets/WidgetsFrame.a33f6bb5.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.fdf790e0.js","assets/broker.1fe265d9.css","assets/DashPlayer.52c5e4a6.js","assets/geometryUtils.dec88751.js","assets/DashPlayer.b0953bcd.css","assets/asyncComputed.6f213f9d.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class P{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}(async()=>{await k();const e=u({render:()=>b(D)});l.init(),f(e,r),P.init(),e.use(r),e.use(h),e.mount("#app"),e.component("VSelect",m),e.component("Markdown",y),e.component("Message",g),s(e,v),s(e,w),s(e,I)})();
//# sourceMappingURL=player.d418f9e4.js.map
