import{cG as n}from"./outputWidgets.5ced94d7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="1426c7cf-c6cb-45b9-9fde-3606c7292737",e._sentryDebugIdIdentifier="sentry-dbid-1426c7cf-c6cb-45b9-9fde-3606c7292737")}catch{}})();const c=(e,r)=>{n.error({message:e,description:r})};export{c as p};
//# sourceMappingURL=popupNotifcation.2a7681be.js.map
