import"./outputWidgets.5ced94d7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="d14585d3-ed31-4c47-bce5-6c617649da75",e._sentryDebugIdIdentifier="sentry-dbid-d14585d3-ed31-4c47-bce5-6c617649da75")}catch{}})();const r=e=>{try{return new URL(e),!0}catch{return!1}};export{r as i};
//# sourceMappingURL=url.b91ad4a3.js.map
