import{S as c}from"./Sidebar.d083b372.js";import{_ as p}from"./Navbar.vue_vue_type_script_setup_true_lang.2a7c3217.js";import{G as d,H as l,I as u}from"./icons.157295a5.js";import{d as b,eA as f,J as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.5ced94d7.js";import{a as w}from"./asyncComputed.6f213f9d.js";import"./router.c33f3e79.js";import{O as z}from"./organization.44bb6c7b.js";import"./index.13e3df9c.js";import{B as h}from"./BaseLayout.a4af420b.js";import"./Tooltip.9bafe9e8.js";import"./logo.084e5d7c.js";import"./index.8ea91ac5.js";import"./Title.74cb802d.js";import"./index.fe1573f2.js";import"./index.2a4a437f.js";import"./index.48bbb941.js";import"./gateway.06420003.js";import"./activeRecord.6ae8bce9.js";import"./pubsub.f395e26b.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="e7fb0466-caad-45e8-a379-dacad0c89305",a._sentryDebugIdIdentifier="sentry-dbid-e7fb0466-caad-45e8-a379-dacad0c89305")}catch{}})();const q=b({__name:"Organization",setup(a){const n=f().params.organizationId,{result:o}=w(()=>z.get(n)),i=g(()=>o.value?[{label:"My organizations",path:"/organizations"},{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(p,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(c,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{q as default};
//# sourceMappingURL=Organization.79b4a710.js.map
