import{R as d}from"./Title.74cb802d.js";import{F as n}from"./outputWidgets.5ced94d7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="2f3d5e76-b863-4b5b-ade4-f8062abe4c63",e._sentryDebugIdIdentifier="sentry-dbid-2f3d5e76-b863-4b5b-ade4-f8062abe4c63")}catch{}})();const s=n(d);export{s as A};
//# sourceMappingURL=index.d48bc6c3.js.map
