import{x as t,b as s,eu as o}from"./outputWidgets.5ced94d7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="9b002531-5141-4995-a9eb-48e7567c1d23",e._sentryDebugIdIdentifier="sentry-dbid-9b002531-5141-4995-a9eb-48e7567c1d23")}catch{}})();const r={},i={class:"organization-settings"};function a(e,n){return s(),o("div",i,"Organization settings")}const f=t(r,[["render",a]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.43d7405f.js.map
