import{v as s}from"./icons.157295a5.js";import{d as r,a as c,b as d,eu as i,f as _,u as l,aJ as u,x as b}from"./outputWidgets.5ced94d7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="470a7b0a-ca82-4891-b341-00d354ae30db",e._sentryDebugIdIdentifier="sentry-dbid-470a7b0a-ca82-4891-b341-00d354ae30db")}catch{}})();const f=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(a,n)=>{const o=c("icon");return d(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=p=>t("exitFullscreenPreview"))},[_(o,{class:"icon",path:l(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),u(" Editor ")])}}});const v=b(f,[["__scopeId","data-v-eaeb3a6e"]]);export{v as B};
//# sourceMappingURL=BackButton.77695c64.js.map
