import{W as a}from"./outputWidgets.5ced94d7.js";import{c as s,d as i}from"./index.280a7171.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="cade21ec-583b-4e93-8937-d8dedce383fd",e._sentryDebugIdIdentifier="sentry-dbid-cade21ec-583b-4e93-8937-d8dedce383fd")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:d,RangePicker:o}=s(i),b=a(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:o,TimePicker:m,QuarterPicker:d,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(t.name,t),e.component(r.name,r),e.component(d.name,d),e)});export{b as D,t as M,d as Q,o as R,r as W};
//# sourceMappingURL=dayjs.d44490f2.js.map
