import"./outputWidgets.5ced94d7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="9d635920-0b4b-47bd-88a6-2b7597094f50",e._sentryDebugIdIdentifier="sentry-dbid-9d635920-0b4b-47bd-88a6-2b7597094f50")}catch{}})();function d(e){return e.charAt(0).toUpperCase()+e.slice(1)}function a(e,r){const n=e.toLocaleLowerCase().replace(/[^a-z0-9]/g,"_").replace(/_+/g,"_");return r?n:n.replace(/_$/,"")}export{d as c,a as n};
//# sourceMappingURL=string.cd43f06a.js.map
