import{B as p,e as f,a as o,c as h}from"./Title.74cb802d.js";import{W as n,ad as T,f as g,R as l}from"./outputWidgets.5ced94d7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="caaaa87a-2760-46a6-8209-e5c4ca2b3996",e._sentryDebugIdIdentifier="sentry-dbid-caaaa87a-2760-46a6-8209-e5c4ca2b3996")}catch{}})();var w=globalThis&&globalThis.__rest||function(e,r){var s={};for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&r.indexOf(t)<0&&(s[t]=e[t]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var a=0,t=Object.getOwnPropertySymbols(e);a<t.length;a++)r.indexOf(t[a])<0&&Object.prototype.propertyIsEnumerable.call(e,t[a])&&(s[t[a]]=e[t[a]]);return s};const A=()=>l(n(n({},f()),{ellipsis:{type:Boolean,default:void 0}}),["component"]),i=(e,r)=>{let{slots:s,attrs:t}=r;const a=n(n({},e),t),{ellipsis:d,rel:m}=a,b=w(a,["ellipsis","rel"]);T();const u=n(n({},b),{rel:m===void 0&&b.target==="_blank"?"noopener noreferrer":m,ellipsis:!!d,component:"a"});return delete u.navigate,g(p,u,s)};i.displayName="ATypographyLink";i.inheritAttrs=!1;i.props=A();const P=i,O=()=>l(f(),["component"]),c=(e,r)=>{let{slots:s,attrs:t}=r;const a=n(n(n({},e),{component:"div"}),t);return g(p,a,s)};c.displayName="ATypographyParagraph";c.inheritAttrs=!1;c.props=O();const x=c,k=()=>n(n({},l(f(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),y=(e,r)=>{let{slots:s,attrs:t}=r;const{ellipsis:a}=e;T();const d=n(n(n({},e),{ellipsis:a&&typeof a=="object"?l(a,["expandable","rows"]):a,component:"span"}),t);return g(p,d,s)};y.displayName="ATypographyText";y.inheritAttrs=!1;y.props=k();const _=y;o.Text=_;o.Title=h;o.Paragraph=x;o.Link=P;o.Base=p;o.install=function(e){return e.component(o.name,o),e.component(o.Text.displayName,_),e.component(o.Title.displayName,h),e.component(o.Paragraph.displayName,x),e.component(o.Link.displayName,P),e};export{x as A,P as L,_ as a};
//# sourceMappingURL=index.8ea91ac5.js.map
