import"./outputWidgets.5ced94d7.js";import{M as r}from"./Title.74cb802d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="a502e0cf-e545-4e1b-93b4-3bd3bd577a9c",e._sentryDebugIdIdentifier="sentry-dbid-a502e0cf-e545-4e1b-93b4-3bd3bd577a9c")}catch{}})();function o(e){switch(typeof e){case"object":return Object.entries(e).map(([t,n])=>({title:t,key:t,children:o(n)}));default:return[{title:e,key:e}]}}function d(e){return new Promise(t=>{r.confirm({title:e,onOk:()=>t(!0),onCancel:()=>t(!1)})})}export{d as a,o as t};
//# sourceMappingURL=ant-design.49bf0c8e.js.map
