import{d as g,ez as v,eA as k,r as b,b as r,c as s,w as a,u as e,f as p,ew as n}from"./outputWidgets.5ced94d7.js";import{S as w,L as j}from"./SmartConsole.2af8d0ee.js";import{a as x}from"./asyncComputed.6f213f9d.js";import{J as I}from"./jobs.b1195529.js";import{_ as B}from"./SaveButton.vue_vue_type_script_setup_true_lang.5baa60de.js";import{_ as C}from"./DocsButton.vue_vue_type_script_setup_true_lang.b7605154.js";import{B as S}from"./BaseLayout.a4af420b.js";import{_ as T,a as A}from"./JobSettings.vue_vue_type_script_setup_true_lang.d46e3984.js";import{c as D}from"./index.2a4a437f.js";import{A as _,T as R}from"./TabPane.d9f04984.js";import"./forms.4a767921.js";import"./activeRecord.6ae8bce9.js";import"./pubsub.f395e26b.js";import"./dashes.11209ba2.js";import"./index.48bbb941.js";import"./hooks.eb6be727.js";import"./workspaces.2720be7e.js";import"./url.b91ad4a3.js";import"./icons.157295a5.js";import"./Title.74cb802d.js";import"./index.d48bc6c3.js";import"./uuid.3b98222f.js";import"./ant-design.49bf0c8e.js";import"./RunButton.vue_vue_type_script_setup_true_lang.1dff2367.js";import"./index.280a7171.js";import"./index.54325f84.js";import"./dayjs.75fd0727.js";import"./Form.3717142f.js";import"./index.fe1573f2.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[m]="1c5f4c3e-9669-436c-bc71-03bbc304c344",i._sentryDebugIdIdentifier="sentry-dbid-1c5f4c3e-9669-436c-bc71-03bbc304c344")}catch{}})();const me=g({__name:"JobEditor",setup(i){const m=v(),u=k(),l=b(null),o=b("test");function y(){m.push({name:"jobs"})}const{result:t}=x(()=>I.get(u.params.jobId)),f=j.create();return($,d)=>(r(),s(S,null,{navbar:a(()=>[e(t)?(r(),s(e(D),{key:0,title:e(t).title,style:{padding:"5px 10px"},onBack:y},{footer:a(()=>[p(e(R),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=c=>o.value=c)},{default:a(()=>[p(e(_),{key:"test",tab:"Test"}),p(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[p(C),o.value==="settings"?(r(),s(B,{key:0,model:e(t)},null,8,["model"])):n("",!0)]),_:1},8,["title"])):n("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(T,{key:0,ref_key:"tester",ref:l,job:e(t),"log-service":e(f)},null,8,["job","log-service"])):n("",!0),e(t)&&o.value==="settings"?(r(),s(A,{key:1,job:e(t)},null,8,["job"])):n("",!0)]),footer:a(()=>{var c;return[e(t)&&o.value==="test"?(r(),s(w,{key:0,runtime:"forms","log-service":e(f),onRestart:(c=l.value)==null?void 0:c.test},null,8,["log-service","onRestart"])):n("",!0)]}),_:1}))}});export{me as default};
//# sourceMappingURL=JobEditor.024aa8f7.js.map
