import"./outputWidgets.5ced94d7.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="4860d1cf-5d9e-44de-9acb-b107a3af0b59",x._sentryDebugIdIdentifier="sentry-dbid-4860d1cf-5d9e-44de-9acb-b107a3af0b59")}catch{}})();const d=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)}),r=()=>Math.random().toString(36).slice(2);export{r,d as u};
//# sourceMappingURL=uuid.3b98222f.js.map
