import{d as f,eA as u,J as b,b as y,c as g,u as _}from"./outputWidgets.5ced94d7.js";import{a as w}from"./asyncComputed.6f213f9d.js";import"./router.c33f3e79.js";import{M as n}from"./member.87d26496.js";import"./index.13e3df9c.js";import{C as I}from"./CrudView.1c9778e2.js";import"./Title.74cb802d.js";import"./index.48bbb941.js";import"./gateway.06420003.js";import"./activeRecord.6ae8bce9.js";import"./pubsub.f395e26b.js";import"./icons.157295a5.js";import"./index.8ea91ac5.js";import"./Form.3717142f.js";import"./url.b91ad4a3.js";import"./index.54325f84.js";import"./index.d48bc6c3.js";import"./index.c946e10c.js";import"./index.fe1573f2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="5ec36e5f-9f56-4087-902f-cafd23e73c36",e._sentryDebugIdIdentifier="sentry-dbid-5ec36e5f-9f56-4087-902f-cafd23e73c36")}catch{}})();const F=f({__name:"Members",setup(e){const r=u().params.organizationId,m=[{key:"email",label:"Email"}],s=async t=>{await n.create(r,t.email),c()},{loading:l,result:d,refetch:c}=w(()=>n.list(r)),p=b(()=>{var t,a;return{columns:[{name:"Email"},{name:"Role"}],rows:(a=(t=d.value)==null?void 0:t.map(i=>({key:i.email,cells:[{text:i.email},{text:i.role}]})))!=null?a:[]}});return(t,a)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:p.value,"create-button-text":"Add members",fields:m,onCreate:s},null,8,["loading","table"]))}});export{F as default};
//# sourceMappingURL=Members.61967f9b.js.map
